import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import * as React from 'react';
import React__default, { createContext, PureComponent, Component, createRef } from 'react';
import PropTypes from 'prop-types';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { freeze, isPlainObject, isAllOf, createSelector, createSlice } from '@reduxjs/toolkit';
import { QueryStatus } from '@reduxjs/toolkit/query';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import jss from 'jss';
import preset from 'jss-preset-default';
import { createStyling, getBase16Theme, invertTheme } from 'react-base16-styling';
import rgba from 'hex-rgba';
import * as reduxThemes from 'redux-devtools-themes';
import { Select } from '@redux-devtools/ui';
import debounce from 'lodash.debounce';
import _typeof from '@babel/runtime/helpers/typeof';
import { isKeyed, isIndexed, isCollection } from 'immutable';
import { QueryStatus as QueryStatus$1 } from '@reduxjs/toolkit/dist/query';
import { JSONTree } from 'react-json-tree';

var QueryPreviewTabs;

(function (QueryPreviewTabs) {
  QueryPreviewTabs[QueryPreviewTabs["queryinfo"] = 0] = "queryinfo";
  QueryPreviewTabs[QueryPreviewTabs["apiConfig"] = 1] = "apiConfig";
  QueryPreviewTabs[QueryPreviewTabs["querySubscriptions"] = 2] = "querySubscriptions";
  QueryPreviewTabs[QueryPreviewTabs["queryTags"] = 3] = "queryTags";
  QueryPreviewTabs[QueryPreviewTabs["actions"] = 4] = "actions";
})(QueryPreviewTabs || (QueryPreviewTabs = {}));

var _mapStatusToFactor, _queryComparators;
var QueryComparators;

(function (QueryComparators) {
  QueryComparators["fulfilledTimeStamp"] = "timestamp";
  QueryComparators["queryKey"] = "key";
  QueryComparators["status"] = "status";
  QueryComparators["endpointName"] = "endpointName";
  QueryComparators["apiReducerPath"] = "apiReducerPath";
})(QueryComparators || (QueryComparators = {}));

var sortQueryOptions = [{
  label: 'last updated',
  value: QueryComparators.fulfilledTimeStamp
}, {
  label: 'query key',
  value: QueryComparators.queryKey
}, {
  label: 'status',
  value: QueryComparators.status
}, {
  label: 'endpoint',
  value: QueryComparators.endpointName
}, {
  label: 'reducerPath',
  value: QueryComparators.apiReducerPath
}];

function sortQueryByFulfilled(thisQueryInfo, thatQueryInfo) {
  var _thisQueryInfo$state$, _thatQueryInfo$state$;

  var thisFulfilled = (_thisQueryInfo$state$ = thisQueryInfo.state.fulfilledTimeStamp) !== null && _thisQueryInfo$state$ !== void 0 ? _thisQueryInfo$state$ : -1;
  var thatFulfilled = (_thatQueryInfo$state$ = thatQueryInfo.state.fulfilledTimeStamp) !== null && _thatQueryInfo$state$ !== void 0 ? _thatQueryInfo$state$ : -1;
  return thisFulfilled - thatFulfilled;
}

var mapStatusToFactor = (_mapStatusToFactor = {}, _defineProperty(_mapStatusToFactor, QueryStatus.uninitialized, 1), _defineProperty(_mapStatusToFactor, QueryStatus.pending, 2), _defineProperty(_mapStatusToFactor, QueryStatus.rejected, 3), _defineProperty(_mapStatusToFactor, QueryStatus.fulfilled, 4), _mapStatusToFactor);

function sortQueryByStatus(thisQueryInfo, thatQueryInfo) {
  var thisTerm = mapStatusToFactor[thisQueryInfo.state.status] || -1;
  var thatTerm = mapStatusToFactor[thatQueryInfo.state.status] || -1;
  return thisTerm - thatTerm;
}

function compareJSONPrimitive(a, b) {
  if (a === b) {
    return 0;
  }

  return a > b ? 1 : -1;
}

function sortByQueryKey(thisQueryInfo, thatQueryInfo) {
  return compareJSONPrimitive(thisQueryInfo.queryKey, thatQueryInfo.queryKey);
}

function sortQueryByEndpointName(thisQueryInfo, thatQueryInfo) {
  var _thisQueryInfo$state$2, _thatQueryInfo$state$2;

  var thisEndpointName = (_thisQueryInfo$state$2 = thisQueryInfo.state.endpointName) !== null && _thisQueryInfo$state$2 !== void 0 ? _thisQueryInfo$state$2 : '';
  var thatEndpointName = (_thatQueryInfo$state$2 = thatQueryInfo.state.endpointName) !== null && _thatQueryInfo$state$2 !== void 0 ? _thatQueryInfo$state$2 : '';
  return compareJSONPrimitive(thisEndpointName, thatEndpointName);
}

function sortByApiReducerPath(thisQueryInfo, thatQueryInfo) {
  return compareJSONPrimitive(thisQueryInfo.reducerPath, thatQueryInfo.reducerPath);
}

var queryComparators = (_queryComparators = {}, _defineProperty(_queryComparators, QueryComparators.fulfilledTimeStamp, sortQueryByFulfilled), _defineProperty(_queryComparators, QueryComparators.status, sortQueryByStatus), _defineProperty(_queryComparators, QueryComparators.endpointName, sortQueryByEndpointName), _defineProperty(_queryComparators, QueryComparators.queryKey, sortByQueryKey), _defineProperty(_queryComparators, QueryComparators.apiReducerPath, sortByApiReducerPath), _queryComparators);

var _queryListFilters;

var QueryFilters;

(function (QueryFilters) {
  QueryFilters["queryKey"] = "query key";
  QueryFilters["reducerPath"] = "reducerPath";
  QueryFilters["endpointName"] = "endpoint";
  QueryFilters["status"] = "status";
})(QueryFilters || (QueryFilters = {}));

function filterByQueryKey(regex, list) {
  if (!regex) {
    return list;
  }

  return list.filter(function (RtkResourceInfo) {
    return regex.test(RtkResourceInfo.queryKey);
  });
}

function filterByReducerPath(regex, list) {
  if (!regex) {
    return list;
  }

  return list.filter(function (RtkResourceInfo) {
    return regex.test(RtkResourceInfo.reducerPath);
  });
}

function filterByEndpointName(regex, list) {
  if (!regex) {
    return list;
  }

  return list.filter(function (RtkResourceInfo) {
    var _RtkResourceInfo$stat;

    return regex.test((_RtkResourceInfo$stat = RtkResourceInfo.state.endpointName) !== null && _RtkResourceInfo$stat !== void 0 ? _RtkResourceInfo$stat : 'undefined');
  });
}

function filterByStatus(regex, list) {
  if (!regex) {
    return list;
  }

  return list.filter(function (RtkResourceInfo) {
    return regex.test(RtkResourceInfo.state.status);
  });
}

var filterQueryOptions = [{
  label: 'query key',
  value: QueryFilters.queryKey
}, {
  label: 'reducerPath',
  value: QueryFilters.reducerPath
}, {
  label: 'status',
  value: QueryFilters.status
}, {
  label: 'endpoint',
  value: QueryFilters.endpointName
}];
var queryListFilters = (_queryListFilters = {}, _defineProperty(_queryListFilters, QueryFilters.queryKey, filterByQueryKey), _defineProperty(_queryListFilters, QueryFilters.endpointName, filterByEndpointName), _defineProperty(_queryListFilters, QueryFilters.reducerPath, filterByReducerPath), _defineProperty(_queryListFilters, QueryFilters.status, filterByStatus), _queryListFilters);

var emptyArray = freeze([]);
var emptyRecord = freeze({});
function identity(val) {
  return val;
}

// https://stackoverflow.com/a/9310752
function escapeRegExpSpecialCharacter(text) {
  return text.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, '\\$&');
}

var DATA_TYPE_KEY = Symbol.for('__serializedType__');
/**
 * @see https://github.com/reduxjs/redux-toolkit/blob/b718e01d323d3ab4b913e5d88c9b90aa790bb975/src/query/core/buildSlice.ts#L259
 */

var missingTagId = '__internal_without_id';

function formatMs(milliseconds) {
  if (!Number.isFinite(milliseconds)) {
    return 'NaN';
  }

  var absInput = Math.abs(Math.round(milliseconds));
  var millis = (absInput % 1000).toString();

  if (millis.length < 3) {
    if (millis.length === 2) {
      millis = '0' + millis;
    } else {
      millis = '00' + millis;
    }
  }

  var seconds = Math.floor(absInput / 1000) % 60;
  var minutes = Math.floor(absInput / 60000);
  var output = "".concat(seconds, ".").concat(millis, "s");

  if (minutes > 0) {
    output = "".concat(minutes, "m").concat(output);
  }

  if (milliseconds < 0) {
    output = "-".concat(output);
  }

  return output;
}

/**
 * An implementation of `Kahan-Babuska algorithm`
 * that reduces numerical floating point errors.
 * @param {number[]} nums
 * @returns {number}
 * @see https://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.582.288&rep=rep1&type=pdf
 */
function sum(nums) {
  if (nums.length === 0) {
    return 0;
  }

  var t;
  var correction = 0;
  var output = nums[0];

  for (var i = 1, len = nums.length; i < len; i++) {
    t = output + nums[i];

    if (Math.abs(output) >= Math.abs(nums[i])) {
      correction += output - t + nums[i];
    } else {
      correction += nums[i] - t + output;
    }

    output = t;
  }

  return output + correction;
}
/**
 * Returns mean, also known as average, of numerical sequences.
 * @param nums
 * @returns
 */


function mean(nums) {
  if (nums.length === 0) {
    return NaN;
  }

  return +(sum(nums) / nums.length).toFixed(6);
}
/**
 * Returns median value of a numeric sequence.
 * @param nums
 * @returns
 */

function median(nums) {
  var len = nums.length;

  if (len === 0) {
    return NaN;
  }

  if (len === 1) {
    return nums[0];
  }

  var sorted = nums.slice().sort();

  if (len % 2 === 1) {
    return sorted[(len + 1) / 2 - 1];
  }

  return +(0.5 * (sorted[len / 2 - 1] + sorted[len / 2])).toFixed(6);
}

var rtkqueryApiStateKeys = ['queries', 'mutations', 'config', 'provided', 'subscriptions'];
/**
 * Type guard used to select apis from the user store state.
 * @param val
 * @returns {boolean}
 */

function isApiSlice(val) {
  if (!isPlainObject(val)) {
    return false;
  }

  for (var i = 0, len = rtkqueryApiStateKeys.length; i < len; i++) {
    if (!isPlainObject(val[rtkqueryApiStateKeys[i]])) {
      return false;
    }
  }

  return true;
}
/**
 * Indexes api states by their `reducerPath`.
 *
 * Returns `null` if there are no api slice or `reduxStoreState`
 * is not an object.
 *
 * @param reduxStoreState
 * @returns
 */

function getApiStatesOf(reduxStoreState) {
  if (!isPlainObject(reduxStoreState)) {
    return null;
  }

  var output = {};
  var keys = Object.keys(reduxStoreState);

  for (var i = 0, len = keys.length; i < len; i++) {
    var key = keys[i];
    var value = reduxStoreState[key];

    if (isApiSlice(value)) {
      output[key] = value;
    }
  }

  if (Object.keys(output).length === 0) {
    return null;
  }

  return output;
}
function extractAllApiQueries(apiStatesByReducerPath) {
  if (!apiStatesByReducerPath) {
    return emptyArray;
  }

  var reducerPaths = Object.keys(apiStatesByReducerPath);
  var output = [];

  for (var i = 0, len = reducerPaths.length; i < len; i++) {
    var reducerPath = reducerPaths[i];
    var api = apiStatesByReducerPath[reducerPath];
    var queryKeys = Object.keys(api.queries);

    for (var j = 0, qKeysLen = queryKeys.length; j < qKeysLen; j++) {
      var queryKey = queryKeys[j];
      var state = api.queries[queryKey];

      if (state) {
        output.push({
          type: 'query',
          reducerPath: reducerPath,
          queryKey: queryKey,
          state: state
        });
      }
    }
  }

  return output;
}
function extractAllApiMutations(apiStatesByReducerPath) {
  if (!apiStatesByReducerPath) {
    return emptyArray;
  }

  var reducerPaths = Object.keys(apiStatesByReducerPath);
  var output = [];

  for (var i = 0, len = reducerPaths.length; i < len; i++) {
    var reducerPath = reducerPaths[i];
    var api = apiStatesByReducerPath[reducerPath];
    var mutationKeys = Object.keys(api.mutations);

    for (var j = 0, mKeysLen = mutationKeys.length; j < mKeysLen; j++) {
      var queryKey = mutationKeys[j];
      var state = api.mutations[queryKey];

      if (state) {
        output.push({
          type: 'mutation',
          reducerPath: reducerPath,
          queryKey: queryKey,
          state: state
        });
      }
    }
  }

  return output;
}

function computeQueryTallyOf(queryState) {
  var queries = Object.values(queryState);
  var output = {
    count: 0
  };

  for (var i = 0, len = queries.length; i < len; i++) {
    var query = queries[i];

    if (query) {
      output.count++;

      if (!output[query.status]) {
        output[query.status] = 1;
      } else {
        output[query.status]++;
      }
    }
  }

  return output;
}

function tallySubscriptions(subsState) {
  var subsOfQueries = Object.values(subsState);
  var output = 0;

  for (var i = 0, len = subsOfQueries.length; i < len; i++) {
    var subsOfQuery = subsOfQueries[i];

    if (subsOfQuery) {
      output += Object.keys(subsOfQuery).length;
    }
  }

  return output;
}

function computeRtkQueryRequests(type, api, sortedActions, currentStateIndex) {
  var _api$type;

  var requestById = {};
  var matcher = type === 'queries' ? matchesExecuteQuery(api.config.reducerPath) : matchesExecuteMutation(api.config.reducerPath);

  for (var i = 0, len = sortedActions.length; i < len && i <= currentStateIndex; i++) {
    var action = sortedActions[i];

    if (matcher(action)) {
      var requestRecord = requestById[action.meta.requestId];

      if (!requestRecord) {
        var _action$meta, _action$meta$arg, _action$meta$arg$endp, _action$meta2, _action$meta2$arg;

        var queryCacheKey = (_action$meta = action.meta) === null || _action$meta === void 0 ? void 0 : (_action$meta$arg = _action$meta.arg) === null || _action$meta$arg === void 0 ? void 0 : _action$meta$arg.queryCacheKey;
        var queryKey = typeof queryCacheKey === 'string' ? queryCacheKey : action.meta.requestId;
        var endpointName = (_action$meta$arg$endp = (_action$meta2 = action.meta) === null || _action$meta2 === void 0 ? void 0 : (_action$meta2$arg = _action$meta2.arg) === null || _action$meta2$arg === void 0 ? void 0 : _action$meta2$arg.endpointName) !== null && _action$meta$arg$endp !== void 0 ? _action$meta$arg$endp : '-';
        requestById[action.meta.requestId] = requestRecord = {
          queryKey: queryKey,
          requestId: action.meta.requestId,
          endpointName: endpointName,
          status: action.meta.requestStatus
        };
      }

      requestRecord.status = action.meta.requestStatus;

      if (action.meta.requestStatus === QueryStatus.pending && typeof action.meta.startedTimeStamp === 'number') {
        requestRecord.startedTimeStamp = action.meta.startedTimeStamp;
      }

      if (action.meta.requestStatus === QueryStatus.fulfilled && typeof action.meta.fulfilledTimeStamp === 'number') {
        requestRecord.fulfilledTimeStamp = action.meta.fulfilledTimeStamp;
      }
    }
  }

  var requestIds = Object.keys(requestById); // Patch queries that have pending actions that are committed

  for (var _i = 0, _len = requestIds.length; _i < _len; _i++) {
    var requestId = requestIds[_i];
    var request = requestById[requestId];

    if (typeof request.startedTimeStamp === 'undefined' && typeof request.fulfilledTimeStamp === 'number') {
      var _api$type$request$que;

      var startedTimeStampFromCache = (_api$type$request$que = api[type][request.queryKey]) === null || _api$type$request$que === void 0 ? void 0 : _api$type$request$que.startedTimeStamp;

      if (typeof startedTimeStampFromCache === 'number') {
        request.startedTimeStamp = startedTimeStampFromCache;
      }
    }
  } // Add queries that have pending and fulfilled actions committed


  var queryCacheEntries = Object.entries((_api$type = api[type]) !== null && _api$type !== void 0 ? _api$type : {});

  for (var _i2 = 0, _len2 = queryCacheEntries.length; _i2 < _len2; _i2++) {
    var _queryCache$requestId;

    var _queryCacheEntries$_i = _slicedToArray(queryCacheEntries[_i2], 2),
        _queryCacheKey = _queryCacheEntries$_i[0],
        queryCache = _queryCacheEntries$_i[1];

    var _requestId = type === 'queries' ? (_queryCache$requestId = queryCache === null || queryCache === void 0 ? void 0 : queryCache.requestId) !== null && _queryCache$requestId !== void 0 ? _queryCache$requestId : '' : _queryCacheKey;

    if (queryCache && !Object.prototype.hasOwnProperty.call(requestById, _requestId)) {
      var startedTimeStamp = queryCache === null || queryCache === void 0 ? void 0 : queryCache.startedTimeStamp;
      var fulfilledTimeStamp = queryCache === null || queryCache === void 0 ? void 0 : queryCache.fulfilledTimeStamp;

      if (typeof startedTimeStamp === 'number' && typeof fulfilledTimeStamp === 'number') {
        var _queryCache$endpointN;

        requestById[_requestId] = {
          queryKey: _queryCacheKey,
          requestId: _requestId,
          endpointName: (_queryCache$endpointN = queryCache.endpointName) !== null && _queryCache$endpointN !== void 0 ? _queryCache$endpointN : '',
          startedTimeStamp: startedTimeStamp,
          fulfilledTimeStamp: fulfilledTimeStamp,
          status: queryCache.status
        };
      }
    }
  }

  return requestById;
}

function formatRtkRequest(rtkRequest) {
  if (!rtkRequest) {
    return null;
  }

  var fulfilledTimeStamp = rtkRequest.fulfilledTimeStamp;
  var startedTimeStamp = rtkRequest.startedTimeStamp;
  var output = {
    queryKey: rtkRequest.queryKey,
    requestId: rtkRequest.requestId,
    endpointName: rtkRequest.endpointName,
    startedAt: '-',
    completedAt: '-',
    duration: '-'
  };

  if (typeof fulfilledTimeStamp === 'number' && typeof startedTimeStamp === 'number') {
    output.startedAt = new Date(startedTimeStamp).toISOString();
    output.completedAt = new Date(fulfilledTimeStamp).toISOString();
    output.duration = formatMs(fulfilledTimeStamp - startedTimeStamp);
  }

  return output;
}

function computeQueryApiTimings(requestById) {
  var requests = Object.values(requestById);
  var latestRequest = null;
  var oldestRequest = null;
  var slowestRequest = null;
  var fastestRequest = null;
  var slowestDuration = 0;
  var fastestDuration = Number.MAX_SAFE_INTEGER;
  var pendingDurations = [];

  for (var i = 0, len = requests.length; i < len; i++) {
    var request = requests[i];
    var fulfilledTimeStamp = request.fulfilledTimeStamp,
        startedTimeStamp = request.startedTimeStamp;

    if (typeof fulfilledTimeStamp === 'number') {
      var _latestRequest, _oldestRequest;

      var latestFulfilledTimeStamp = ((_latestRequest = latestRequest) === null || _latestRequest === void 0 ? void 0 : _latestRequest.fulfilledTimeStamp) || 0;
      var oldestFulfilledTimeStamp = ((_oldestRequest = oldestRequest) === null || _oldestRequest === void 0 ? void 0 : _oldestRequest.fulfilledTimeStamp) || Number.MAX_SAFE_INTEGER;

      if (fulfilledTimeStamp > latestFulfilledTimeStamp) {
        latestRequest = request;
      }

      if (fulfilledTimeStamp < oldestFulfilledTimeStamp) {
        oldestRequest = request;
      }

      if (typeof startedTimeStamp === 'number' && startedTimeStamp <= fulfilledTimeStamp) {
        var pendingDuration = fulfilledTimeStamp - startedTimeStamp;
        pendingDurations.push(pendingDuration);

        if (pendingDuration > slowestDuration) {
          slowestDuration = pendingDuration;
          slowestRequest = request;
        }

        if (pendingDuration < fastestDuration) {
          fastestDuration = pendingDuration;
          fastestRequest = request;
        }
      }
    }
  }

  var average = pendingDurations.length > 0 ? formatMs(mean(pendingDurations)) : '-';
  var median$1 = pendingDurations.length > 0 ? formatMs(median(pendingDurations)) : '-';
  return {
    latest: formatRtkRequest(latestRequest),
    oldest: formatRtkRequest(oldestRequest),
    slowest: formatRtkRequest(slowestRequest),
    fastest: formatRtkRequest(fastestRequest),
    average: average,
    median: median$1
  };
}

function computeApiTimings(api, actionsById, currentStateIndex) {
  var sortedActions = Object.entries(actionsById).sort(function (thisAction, thatAction) {
    return compareJSONPrimitive(Number(thisAction[0]), Number(thatAction[0]));
  }).map(function (entry) {
    return entry[1].action;
  });
  var queryRequestsById = computeRtkQueryRequests('queries', api, sortedActions, currentStateIndex);
  var mutationRequestsById = computeRtkQueryRequests('mutations', api, sortedActions, currentStateIndex);
  return {
    queries: computeQueryApiTimings(queryRequestsById),
    mutations: computeQueryApiTimings(mutationRequestsById)
  };
}

function generateApiStatsOfCurrentQuery(api, actionsById, currentStateIndex) {
  if (!api) {
    return null;
  }

  return {
    timings: computeApiTimings(api, actionsById, currentStateIndex),
    tally: {
      cachedQueries: computeQueryTallyOf(api.queries),
      cachedMutations: computeQueryTallyOf(api.mutations),
      tagTypes: Object.keys(api.provided).length,
      subscriptions: tallySubscriptions(api.subscriptions)
    }
  };
}
function flipComparator(comparator) {
  return function flipped(a, b) {
    return comparator(b, a);
  };
}
function isQuerySelected(selectedQueryKey, queryInfo) {
  return !!selectedQueryKey && selectedQueryKey.queryKey === queryInfo.queryKey && selectedQueryKey.reducerPath === queryInfo.reducerPath;
}
function getQueryTagsOf(resInfo, provided) {
  if (!resInfo || resInfo.type === 'mutation' || !provided) {
    return emptyArray;
  }

  var tagTypes = Object.keys(provided);

  if (tagTypes.length < 1) {
    return emptyArray;
  }

  var output = [];

  for (var _i3 = 0, _Object$entries = Object.entries(provided); _i3 < _Object$entries.length; _i3++) {
    var _Object$entries$_i = _slicedToArray(_Object$entries[_i3], 2),
        type = _Object$entries$_i[0],
        tagIds = _Object$entries$_i[1];

    if (tagIds) {
      for (var _i4 = 0, _Object$entries2 = Object.entries(tagIds); _i4 < _Object$entries2.length; _i4++) {
        var _Object$entries2$_i = _slicedToArray(_Object$entries2[_i4], 2),
            id = _Object$entries2$_i[0],
            queryKeys = _Object$entries2$_i[1];

        if (queryKeys.includes(resInfo.queryKey)) {
          var tag = {
            type: type
          };

          if (id !== missingTagId) {
            tag.id = id;
          }

          output.push(tag);
        }
      }
    }
  }

  return output;
}
/**
 * Computes query status flags.
 * @param status
 * @see https://redux-toolkit.js.org/rtk-query/usage/queries#frequently-used-query-hook-return-values
 * @see https://github.com/reduxjs/redux-toolkit/blob/b718e01d323d3ab4b913e5d88c9b90aa790bb975/src/query/core/apiState.ts#L63
 */

function getQueryStatusFlags(_ref) {
  var status = _ref.status,
      data = _ref.data;
  return {
    isUninitialized: status === QueryStatus.uninitialized,
    isFetching: status === QueryStatus.pending,
    isSuccess: status === QueryStatus.fulfilled && !!data,
    isError: status === QueryStatus.rejected
  };
}

function matchesQueryKey(queryKey) {
  return function (action) {
    var _action$meta4, _action$meta4$arg;

    return (action === null || action === void 0 ? void 0 : (_action$meta4 = action.meta) === null || _action$meta4 === void 0 ? void 0 : (_action$meta4$arg = _action$meta4.arg) === null || _action$meta4$arg === void 0 ? void 0 : _action$meta4$arg.queryCacheKey) === queryKey;
  };
}

function macthesRequestId(requestId) {
  return function (action) {
    var _action$meta5;

    return (action === null || action === void 0 ? void 0 : (_action$meta5 = action.meta) === null || _action$meta5 === void 0 ? void 0 : _action$meta5.requestId) === requestId;
  };
}

function matchesReducerPath(reducerPath) {
  return function (action) {
    return typeof (action === null || action === void 0 ? void 0 : action.type) === 'string' && action.type.startsWith(reducerPath);
  };
}

function matchesExecuteQuery(reducerPath) {
  return function (action) {
    var _action$meta6, _action$meta7;

    return typeof (action === null || action === void 0 ? void 0 : action.type) === 'string' && action.type.startsWith("".concat(reducerPath, "/executeQuery")) && typeof ((_action$meta6 = action.meta) === null || _action$meta6 === void 0 ? void 0 : _action$meta6.requestId) === 'string' && typeof ((_action$meta7 = action.meta) === null || _action$meta7 === void 0 ? void 0 : _action$meta7.requestStatus) === 'string';
  };
}

function matchesExecuteMutation(reducerPath) {
  return function (action) {
    var _action$meta8, _action$meta9;

    return typeof (action === null || action === void 0 ? void 0 : action.type) === 'string' && action.type.startsWith("".concat(reducerPath, "/executeMutation")) && typeof ((_action$meta8 = action.meta) === null || _action$meta8 === void 0 ? void 0 : _action$meta8.requestId) === 'string' && typeof ((_action$meta9 = action.meta) === null || _action$meta9 === void 0 ? void 0 : _action$meta9.requestStatus) === 'string';
  };
}

function getActionsOfCurrentQuery(currentQuery, actionById) {
  if (!currentQuery) {
    return emptyArray;
  }

  var matcher;

  if (currentQuery.type === 'mutation') {
    matcher = isAllOf(matchesReducerPath(currentQuery.reducerPath), macthesRequestId(currentQuery.queryKey));
  } else {
    matcher = isAllOf(matchesReducerPath(currentQuery.reducerPath), matchesQueryKey(currentQuery.queryKey));
  }

  var output = [];

  for (var _i5 = 0, _Object$entries3 = Object.entries(actionById); _i5 < _Object$entries3.length; _i5++) {
    var _Object$entries3$_i = _slicedToArray(_Object$entries3[_i5], 2),
        liftedAction = _Object$entries3$_i[1];

    if (matcher(liftedAction === null || liftedAction === void 0 ? void 0 : liftedAction.action)) {
      output.push(liftedAction.action);
    }
  }

  return output.length === 0 ? emptyArray : output;
}

function computeSelectorSource(props) {
  var previous = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  var computedStates = props.computedStates,
      currentStateIndex = props.currentStateIndex,
      monitorState = props.monitorState,
      actionsById = props.actionsById;
  var userState = computedStates.length > 0 ? computedStates[currentStateIndex].state : null;

  if (!previous || previous.userState !== userState || previous.monitorState !== monitorState || previous.actionsById !== actionsById) {
    return {
      userState: userState,
      monitorState: monitorState,
      currentStateIndex: currentStateIndex,
      actionsById: actionsById
    };
  }

  return previous;
}
function createInspectorSelectors() {
  var selectQueryComparator = function selectQueryComparator(_ref) {
    var monitorState = _ref.monitorState;
    return queryComparators[monitorState.queryForm.values.queryComparator];
  };

  var selectQueryListFilter = function selectQueryListFilter(_ref2) {
    var monitorState = _ref2.monitorState;
    return queryListFilters[monitorState.queryForm.values.queryFilter];
  };

  var selectActionsById = function selectActionsById(_ref3) {
    var actionsById = _ref3.actionsById;
    return actionsById;
  };

  var selectApiStates = createSelector(function (_ref4) {
    var userState = _ref4.userState;
    return userState;
  }, getApiStatesOf);
  var selectAllQueries = createSelector(selectApiStates, extractAllApiQueries);
  var selectAllMutations = createSelector(selectApiStates, extractAllApiMutations);
  var selectSearchQueryRegex = createSelector(function (_ref5) {
    var monitorState = _ref5.monitorState;
    return monitorState.queryForm.values.searchValue;
  }, function (_ref6) {
    var monitorState = _ref6.monitorState;
    return monitorState.queryForm.values.isRegexSearch;
  }, function (searchValue, isRegexSearch) {
    if (searchValue) {
      try {
        var regexPattern = isRegexSearch ? searchValue : escapeRegExpSpecialCharacter(searchValue);
        return new RegExp(regexPattern, 'i');
      } catch (err) {// We notify that the search regex provided is not valid
      }
    }

    return null;
  });

  var selectComparatorOrder = function selectComparatorOrder(_ref7) {
    var monitorState = _ref7.monitorState;
    return monitorState.queryForm.values.isAscendingQueryComparatorOrder;
  };

  var selectAllVisbileQueries = createSelector([selectQueryComparator, selectQueryListFilter, selectAllQueries, selectAllMutations, selectComparatorOrder, selectSearchQueryRegex], function (comparator, queryListFilter, queryList, mutationsList, isAscending, searchRegex) {
    var filteredList = queryListFilter(searchRegex, queryList.concat(mutationsList));
    var computedComparator = isAscending ? comparator : flipComparator(comparator);
    return filteredList.slice().sort(computedComparator);
  });
  var selectCurrentQueryInfo = createSelector(selectAllQueries, selectAllMutations, function (_ref8) {
    var monitorState = _ref8.monitorState;
    return monitorState.selectedQueryKey;
  }, function (allQueries, allMutations, selectedQueryKey) {
    if (!selectedQueryKey) {
      return null;
    }

    var currentQueryInfo = allQueries.find(function (query) {
      return query.queryKey === selectedQueryKey.queryKey && selectedQueryKey.reducerPath === query.reducerPath;
    }) || null;

    if (!currentQueryInfo) {
      currentQueryInfo = allMutations.find(function (mutation) {
        return mutation.queryKey === selectedQueryKey.queryKey && selectedQueryKey.reducerPath === mutation.reducerPath;
      }) || null;
    }

    return currentQueryInfo;
  });

  var selectApiOfCurrentQuery = function selectApiOfCurrentQuery(selectorsSource) {
    var _apiStates$currentQue;

    var apiStates = selectApiStates(selectorsSource);
    var currentQueryInfo = selectCurrentQueryInfo(selectorsSource);

    if (!apiStates || !currentQueryInfo) {
      return null;
    }

    return (_apiStates$currentQue = apiStates[currentQueryInfo.reducerPath]) !== null && _apiStates$currentQue !== void 0 ? _apiStates$currentQue : null;
  };

  var selectProvidedOfCurrentQuery = function selectProvidedOfCurrentQuery(selectorsSource) {
    var _selectApiOfCurrentQu, _selectApiOfCurrentQu2;

    return (_selectApiOfCurrentQu = (_selectApiOfCurrentQu2 = selectApiOfCurrentQuery(selectorsSource)) === null || _selectApiOfCurrentQu2 === void 0 ? void 0 : _selectApiOfCurrentQu2.provided) !== null && _selectApiOfCurrentQu !== void 0 ? _selectApiOfCurrentQu : null;
  };

  var selectSubscriptionsOfCurrentQuery = createSelector([selectApiOfCurrentQuery, selectCurrentQueryInfo], function (apiState, queryInfo) {
    if (!queryInfo || !apiState) {
      return emptyRecord;
    }

    return apiState.subscriptions[queryInfo.queryKey];
  });
  var selectCurrentQueryTags = createSelector([selectCurrentQueryInfo, selectProvidedOfCurrentQuery], getQueryTagsOf);
  var selectApiStatsOfCurrentQuery = createSelector(selectApiOfCurrentQuery, function (selectorsSource) {
    return selectorsSource.actionsById;
  }, function (selectorsSource) {
    return selectorsSource.currentStateIndex;
  }, generateApiStatsOfCurrentQuery);
  var selectActionsOfCurrentQuery = createSelector(selectCurrentQueryInfo, selectActionsById, getActionsOfCurrentQuery);
  var selectTabCounters = createSelector([selectSubscriptionsOfCurrentQuery, selectActionsOfCurrentQuery, selectCurrentQueryTags], function (subscriptions, actions, tags) {
    var _ref9;

    return _ref9 = {}, _defineProperty(_ref9, QueryPreviewTabs.queryTags, tags.length), _defineProperty(_ref9, QueryPreviewTabs.querySubscriptions, Object.keys(subscriptions !== null && subscriptions !== void 0 ? subscriptions : {}).length), _defineProperty(_ref9, QueryPreviewTabs.apiConfig, 0), _defineProperty(_ref9, QueryPreviewTabs.queryinfo, 0), _defineProperty(_ref9, QueryPreviewTabs.actions, actions.length), _ref9;
  });
  return {
    selectQueryComparator: selectQueryComparator,
    selectApiStates: selectApiStates,
    selectAllQueries: selectAllQueries,
    selectAllVisbileQueries: selectAllVisbileQueries,
    selectSearchQueryRegex: selectSearchQueryRegex,
    selectCurrentQueryInfo: selectCurrentQueryInfo,
    selectCurrentQueryTags: selectCurrentQueryTags,
    selectApiStatsOfCurrentQuery: selectApiStatsOfCurrentQuery,
    selectSubscriptionsOfCurrentQuery: selectSubscriptionsOfCurrentQuery,
    selectApiOfCurrentQuery: selectApiOfCurrentQuery,
    selectTabCounters: selectTabCounters,
    selectActionsOfCurrentQuery: selectActionsOfCurrentQuery
  };
}

function ownKeys$e(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$e(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$e(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$e(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
var initialState = {
  queryForm: {
    values: {
      queryComparator: QueryComparators.fulfilledTimeStamp,
      isAscendingQueryComparatorOrder: false,
      searchValue: '',
      isRegexSearch: false,
      queryFilter: QueryFilters.queryKey
    }
  },
  selectedPreviewTab: QueryPreviewTabs.queryinfo,
  selectedQueryKey: null
};
var monitorSlice = createSlice({
  /**
   * `@@` prefix is mandatory.
   * @see lifedAction @ `packages/redux-devtools-app/src/actions/index.ts`
   */
  name: '@@rtk-query-monitor',
  initialState: initialState,
  reducers: {
    changeQueryFormValues: function changeQueryFormValues(state, action) {
      state.queryForm.values = _objectSpread$e(_objectSpread$e({}, state.queryForm.values), action.payload);
    },
    selectQueryKey: function selectQueryKey(state, action) {
      state.selectedQueryKey = {
        queryKey: action.payload.queryKey,
        reducerPath: action.payload.reducerPath
      };
    },
    selectedPreviewTab: function selectedPreviewTab(state, action) {
      state.selectedPreviewTab = action.payload;
    }
  }
});
function reducer(props, state, action) {
  return monitorSlice.reducer(state, action);
}
var _monitorSlice$actions = monitorSlice.actions,
    selectQueryKey = _monitorSlice$actions.selectQueryKey,
    changeQueryFormValues = _monitorSlice$actions.changeQueryFormValues,
    selectedPreviewTab = _monitorSlice$actions.selectedPreviewTab;

function ownKeys$d(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$d(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$d(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$d(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
jss.setup(preset());
var colorMap = function colorMap(theme) {
  return {
    TEXT_COLOR: theme.base06,
    TEXT_PLACEHOLDER_COLOR: rgba(theme.base06, 60),
    BACKGROUND_COLOR: theme.base00,
    SELECTED_BACKGROUND_COLOR: rgba(theme.base03, 20),
    SKIPPED_BACKGROUND_COLOR: rgba(theme.base03, 10),
    HEADER_BACKGROUND_COLOR: rgba(theme.base03, 30),
    HEADER_BORDER_COLOR: rgba(theme.base03, 20),
    BORDER_COLOR: rgba(theme.base03, 50),
    LIST_BORDER_COLOR: rgba(theme.base03, 50),
    ACTION_TIME_BACK_COLOR: rgba(theme.base03, 20),
    ACTION_TIME_COLOR: theme.base04,
    PIN_COLOR: theme.base04,
    ITEM_HINT_COLOR: rgba(theme.base0F, 90),
    TAB_BACK_SELECTED_COLOR: rgba(theme.base03, 20),
    TAB_BACK_COLOR: rgba(theme.base00, 70),
    TAB_BACK_HOVER_COLOR: rgba(theme.base03, 40),
    TAB_BORDER_COLOR: rgba(theme.base03, 50),
    DIFF_ADD_COLOR: rgba(theme.base0B, 40),
    DIFF_REMOVE_COLOR: rgba(theme.base08, 40),
    DIFF_ARROW_COLOR: theme.base0E,
    LINK_COLOR: rgba(theme.base0E, 90),
    LINK_HOVER_COLOR: theme.base0E,
    ERROR_COLOR: theme.base08,
    ULIST_DISC_COLOR: theme.base0D,
    ULIST_COLOR: rgba(theme.base06, 60),
    ULIST_STRONG_COLOR: theme.base0B,
    TAB_CONTENT_COLOR: rgba(theme.base06, 60),
    TOGGLE_BUTTON_BACKGROUND: rgba(theme.base00, 70),
    TOGGLE_BUTTON_SELECTED_BACKGROUND: theme.base04,
    TOGGLE_BUTTON_ERROR: rgba(theme.base08, 40)
  };
};

var getSheetFromColorMap = function getSheetFromColorMap(map) {
  var appearanceNone = {
    '-webkit-appearance': 'none'
  };
  return {
    inspector: {
      display: 'flex',
      flexFlow: 'column nowrap',
      overflow: 'hidden',
      width: '100%',
      height: '100%',
      'font-family': 'monaco, Consolas, "Lucida Console", monospace',
      'font-size': '12px',
      'font-smoothing': 'antialiased',
      'line-height': '1.5em',
      'background-color': map.BACKGROUND_COLOR,
      color: map.TEXT_COLOR,
      '&[data-wide-layout="1"]': {
        flexFlow: 'row nowrap'
      }
    },
    querySectionWrapper: {
      display: 'flex',
      flex: '0 0 auto',
      height: '50%',
      width: '100%',
      borderColor: map.TAB_BORDER_COLOR,
      '&[data-wide-layout="0"]': {
        borderBottomWidth: 1,
        borderStyle: 'solid'
      },
      '&[data-wide-layout="1"]': {
        height: '100%',
        width: '44%',
        borderRightWidth: 1,
        borderStyle: 'solid'
      },
      flexFlow: 'column nowrap',
      '& > :first-child': {
        flex: '0 0 auto',
        'border-bottom-width': '1px',
        'border-bottom-style': 'solid',
        'border-color': map.LIST_BORDER_COLOR
      },
      '& > :nth-child(n + 2)': {
        flex: '1 1 auto',
        overflowX: 'hidden',
        overflowY: 'auto',
        maxHeight: 'calc(100% - 70px)'
      }
    },
    queryList: {
      listStyle: 'none',
      margin: '0',
      padding: '0'
    },
    queryListItem: {
      'border-bottom-width': '1px',
      'border-bottom-style': 'solid',
      display: 'flex',
      'justify-content': 'space-between',
      padding: '5px 10px',
      cursor: 'pointer',
      'user-select': 'none',
      '&:last-child': {
        'border-bottom-width': 0
      },
      overflow: 'hidden',
      maxHeight: 47,
      'border-bottom-color': map.BORDER_COLOR
    },
    queryListItemKey: {
      display: '-webkit-box',
      boxOrient: 'vertical',
      '-webkit-line-clamp': 2,
      whiteSpace: 'normal',
      overflow: 'hidden',
      width: '100%',
      maxWidth: 'calc(100% - 70px)',
      wordBreak: 'break-all',
      margin: 0
    },
    queryListHeader: {
      display: 'flex',
      padding: 4,
      flex: '0 0 auto',
      'align-items': 'center',
      'border-bottom-width': '1px',
      'border-bottom-style': 'solid',
      'border-color': map.LIST_BORDER_COLOR
    },
    queryStatusWrapper: {
      display: 'flex',
      width: 'auto',
      justifyContent: 'center',
      alignItems: 'center',
      margin: 0,
      flex: '0 0 auto',
      overflow: 'hidden'
    },
    queryType: {
      marginRight: 4
    },
    queryStatus: {
      display: 'inline-flex',
      alignItems: 'center',
      justifyContent: 'center',
      height: 22,
      padding: '0 6px',
      'border-radius': '3px',
      'font-size': '0.7em',
      'line-height': '1em',
      'flex-shrink': 0,
      fontWeight: 700,
      'background-color': map.ACTION_TIME_BACK_COLOR,
      color: map.ACTION_TIME_COLOR
    },
    queryListItemSelected: {
      'background-color': map.SELECTED_BACKGROUND_COLOR
    },
    tabSelector: {
      display: 'flex',
      width: '100%',
      justifyContent: 'flex-end',
      overflow: 'hidden',
      '& > *': {
        flex: '0 1 auto'
      }
    },
    srOnly: {
      position: 'absolute',
      width: 1,
      height: 1,
      padding: 0,
      margin: '-1px',
      overflow: 'hidden',
      clip: 'rect(0,0,0,0)',
      border: 0
    },
    selectorButton: {
      cursor: 'pointer',
      position: 'relative',
      height: '33px',
      padding: '0 8px',
      display: 'inline-flex',
      alignItems: 'center',
      color: map.TEXT_COLOR,
      'border-style': 'solid',
      'border-width': '1px',
      'border-left-width': 0,
      '&:first-child': {
        'border-left-width': '1px',
        'border-top-left-radius': '3px',
        'border-bottom-left-radius': '3px'
      },
      '&:last-child': {
        'border-top-right-radius': '3px',
        'border-bottom-right-radius': '3px'
      },
      'background-color': map.TAB_BACK_COLOR,
      '&:hover': {
        'background-color': map.TAB_BACK_HOVER_COLOR
      },
      'border-color': map.TAB_BORDER_COLOR,
      '& > *': {
        display: '-webkit-box',
        boxOrient: 'vertical',
        '-webkit-line-clamp': 1,
        overflow: 'hidden',
        wordBreak: 'break-all',
        '-webkit-box-pack': 'end',
        paddingBottom: 0
      }
    },
    selectorButtonSmall: {
      padding: '0px 8px',
      'font-size': '0.8em'
    },
    selectorButtonSelected: {
      'background-color': map.TAB_BACK_SELECTED_COLOR
    },
    sortButton: {
      display: 'flex',
      justifyContent: 'space-between',
      alignItems: 'center',
      flexFlow: 'row nowrap',
      cursor: 'pointer',
      position: 'relative',
      padding: '0 8px',
      color: map.TEXT_COLOR,
      borderStyle: 'solid',
      borderWidth: '1px',
      borderRadius: '3px',
      backgroundColor: map.TAB_BACK_COLOR,
      borderColor: map.TAB_BORDER_COLOR,
      height: 30,
      fontSize: 12,
      width: 64,
      '&:active': {
        backgroundColor: map.TAB_BACK_SELECTED_COLOR
      }
    },
    toggleButton: {
      width: '24px',
      height: '24px',
      display: 'inline-block',
      flex: '0 0 auto',
      color: map.TEXT_PLACEHOLDER_COLOR,
      cursor: 'pointer',
      padding: 0,
      fontSize: '0.7em',
      letterSpacing: '-0.7px',
      outline: 'none',
      boxShadow: 'none',
      fontWeight: '700',
      border: 'none',
      '&:hover': {
        color: map.TEXT_COLOR
      },
      backgroundColor: 'transparent',
      '&[aria-pressed="true"]': {
        color: map.BACKGROUND_COLOR,
        backgroundColor: map.TEXT_COLOR
      },
      '&[data-type="error"]': {
        color: map.TEXT_COLOR,
        backgroundColor: map.TOGGLE_BUTTON_ERROR
      }
    },
    queryForm: {
      display: 'flex',
      flexFlow: 'column nowrap'
    },
    sortBySection: {
      display: 'flex',
      padding: '0.4em',
      '& label': {
        display: 'flex',
        flex: '0 0 auto',
        whiteSpace: 'noWrap',
        alignItems: 'center',
        paddingRight: '0.4em'
      },
      '& > :last-child': {
        flex: '0 0 auto',
        marginLeft: '0.4em'
      }
    },
    querySearch: {
      maxWidth: '65%',
      'background-color': map.BACKGROUND_COLOR,
      display: 'flex',
      alignItems: 'center',
      flexFlow: 'row nowrap',
      flex: '1 1 auto',
      paddingRight: 6,
      '& input': {
        outline: 'none',
        border: 'none',
        width: '100%',
        flex: '1 1 auto',
        padding: '5px 10px',
        'font-size': '1em',
        position: 'relative',
        fontFamily: 'monaco, Consolas, "Lucida Console", monospace',
        'background-color': map.BACKGROUND_COLOR,
        color: map.TEXT_COLOR,
        '&::-webkit-input-placeholder': {
          color: map.TEXT_PLACEHOLDER_COLOR
        },
        '&::-moz-placeholder': {
          color: map.TEXT_PLACEHOLDER_COLOR
        },
        '&::-webkit-search-cancel-button': appearanceNone
      }
    },
    closeButton: _objectSpread$d(_objectSpread$d({}, appearanceNone), {}, {
      border: 'none',
      outline: 'none',
      boxShadow: 'none',
      display: 'block',
      flex: '0 0 auto',
      cursor: 'pointer',
      background: 'transparent',
      position: 'relative',
      fontSize: 'inherit',
      '&[data-invisible="1"]': {
        visibility: 'hidden !important'
      },
      '&::after': {
        content: "\"\xD7\"",
        display: 'block',
        padding: 4,
        fontSize: '1.2em',
        color: map.TEXT_PLACEHOLDER_COLOR,
        background: 'transparent'
      },
      '&:hover::after': {
        color: map.TEXT_COLOR
      }
    }),
    noApiFound: {
      width: '100%',
      textAlign: 'center',
      color: map.TEXT_COLOR,
      padding: '1.4em',
      '& a': {
        fontSize: 'inherit',
        color: map.TEXT_COLOR,
        textDecoration: 'underline'
      }
    },
    searchSelectLabel: {
      display: 'inline-block',
      padding: 4,
      borderLeft: '1px solid currentColor'
    },
    queryPreview: {
      flex: '1 1 50%',
      overflowX: 'hidden',
      oveflowY: 'auto',
      display: 'flex',
      'flex-direction': 'column',
      'overflow-y': 'hidden',
      '& pre': {
        border: 'inherit',
        'border-radius': '3px',
        'line-height': 'inherit',
        color: 'inherit'
      },
      'background-color': map.BACKGROUND_COLOR
    },
    previewHeader: {
      flex: '0 0 30px',
      padding: '5px 4px',
      'align-items': 'center',
      'border-bottom-width': '1px',
      'border-bottom-style': 'solid',
      'background-color': map.HEADER_BACKGROUND_COLOR,
      'border-bottom-color': map.HEADER_BORDER_COLOR
    },
    treeItemPin: {
      'font-size': '0.7em',
      'padding-left': '5px',
      cursor: 'pointer',
      '&:hover': {
        'text-decoration': 'underline'
      },
      color: map.PIN_COLOR
    },
    treeItemKey: {
      color: map.TEXT_PLACEHOLDER_COLOR
    },
    treeWrapper: {
      overflowX: 'auto',
      overflowY: 'auto',
      padding: '0.5em 1em'
    },
    tabContent: {
      display: 'block',
      overflowY: 'auto',
      padding: '0.5em 0',
      color: map.TAB_CONTENT_COLOR,
      '& h2': {
        color: map.ULIST_STRONG_COLOR,
        padding: '0.5em 1em',
        fontWeight: 700
      },
      '& h3': {
        color: map.ULIST_STRONG_COLOR
      }
    },
    uList: {
      listStyle: 'none',
      padding: '0 0 0 1em',
      color: map.ULIST_COLOR,
      '& > li': {
        listStyle: 'none'
      },
      '& > li::before': {
        content: '"\\2022"',
        display: 'inline-block',
        paddingRight: '0.5em',
        color: map.ULIST_DISC_COLOR,
        fontSize: '0.8em'
      },
      '& strong': {
        color: map.ULIST_STRONG_COLOR
      }
    }
  };
};

var themeSheet;

var getDefaultThemeStyling = function getDefaultThemeStyling(theme) {
  if (themeSheet) {
    themeSheet.detach();
  }

  themeSheet = jss.createStyleSheet(getSheetFromColorMap(colorMap(theme))).attach();
  return themeSheet.classes;
};

var createStylingFromTheme = createStyling(getDefaultThemeStyling, {
  defaultBase16: reduxThemes.nicinabox,
  base16Themes: _objectSpread$d({}, reduxThemes)
});
function createThemeState(props) {
  var _getBase16Theme;

  var base16Theme = (_getBase16Theme = getBase16Theme(props.theme, _objectSpread$d({}, reduxThemes))) !== null && _getBase16Theme !== void 0 ? _getBase16Theme : reduxThemes.nicinabox;
  var theme = props.invertTheme ? invertTheme(props.theme) : props.theme;
  var styling = createStylingFromTheme(theme);
  return {
    base16Theme: base16Theme,
    styling: styling,
    invertTheme: !!props.invertTheme
  };
}

var mockStyling = function mockStyling() {
  return {
    className: '',
    style: {}
  };
};

var StyleUtilsContext = /*#__PURE__*/createContext({
  base16Theme: reduxThemes.nicinabox,
  invertTheme: false,
  styling: mockStyling
});
function getJsonTreeTheme(base16Theme) {
  return {
    extend: base16Theme,
    nestedNode: function nestedNode(_ref, keyPath, nodeType, expanded) {
      var style = _ref.style;
      return {
        style: _objectSpread$d(_objectSpread$d({}, style), {}, {
          whiteSpace: expanded ? 'inherit' : 'nowrap'
        })
      };
    },
    nestedNodeItemString: function nestedNodeItemString(_ref2, keyPath, nodeType, expanded) {
      var style = _ref2.style;
      return {
        style: _objectSpread$d(_objectSpread$d({}, style), {}, {
          display: expanded ? 'none' : 'inline'
        })
      };
    }
  };
}

function ownKeys$c(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$c(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$c(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$c(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _createSuper$c(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct$c(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct$c() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
var QueryList = /*#__PURE__*/function (_PureComponent) {
  _inherits(QueryList, _PureComponent);

  var _super = _createSuper$c(QueryList);

  function QueryList() {
    _classCallCheck(this, QueryList);

    return _super.apply(this, arguments);
  }

  _createClass(QueryList, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          resInfos = _this$props.resInfos,
          selectedQueryKey = _this$props.selectedQueryKey,
          onSelectQuery = _this$props.onSelectQuery;
      return /*#__PURE__*/React__default.createElement(StyleUtilsContext.Consumer, null, function (_ref) {
        var styling = _ref.styling;
        return /*#__PURE__*/React__default.createElement("ul", _objectSpread$c({}, styling('queryList')), resInfos.map(function (resInfo) {
          var isSelected = isQuerySelected(selectedQueryKey, resInfo);
          return /*#__PURE__*/React__default.createElement("li", _objectSpread$c({
            key: resInfo.queryKey,
            onClick: function onClick() {
              return onSelectQuery(resInfo);
            }
          }, styling(['queryListItem', isSelected && 'queryListItemSelected'], isSelected)), /*#__PURE__*/React__default.createElement("p", _objectSpread$c({}, styling('queryListItemKey')), QueryList.formatQuery(resInfo)), /*#__PURE__*/React__default.createElement("div", _objectSpread$c({}, styling('queryStatusWrapper')), /*#__PURE__*/React__default.createElement("strong", _objectSpread$c({}, styling(['queryStatus', 'queryType'])), resInfo.type === 'query' ? 'Q' : 'M'), /*#__PURE__*/React__default.createElement("p", _objectSpread$c({}, styling('queryStatus')), resInfo.state.status)));
        }));
      });
    }
  }], [{
    key: "isItemSelected",
    value: function isItemSelected(selectedQueryKey, queryInfo) {
      return !!selectedQueryKey && selectedQueryKey.queryKey === queryInfo.queryKey && selectedQueryKey.reducerPath === queryInfo.reducerPath;
    }
  }, {
    key: "formatQuery",
    value: function formatQuery(resInfo) {
      var _resInfo$state$endpoi;

      var key = resInfo.type === 'query' ? resInfo.queryKey : "".concat((_resInfo$state$endpoi = resInfo.state.endpointName) !== null && _resInfo$state$endpoi !== void 0 ? _resInfo$state$endpoi : '', " ").concat(resInfo.queryKey);
      return key;
    }
  }]);

  return QueryList;
}(PureComponent);

function ownKeys$b(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$b(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$b(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$b(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
/* eslint-disable max-len */

/**
 * @see https://icons.getbootstrap.com/icons/arrow-up/
 */

function ArrowUpIcon(props) {
  return /*#__PURE__*/React__default.createElement("svg", _objectSpread$b(_objectSpread$b({
    fill: "currentColor"
  }, props), {}, {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 16 16"
  }), /*#__PURE__*/React__default.createElement("path", {
    fillRule: "evenodd",
    d: "M8 15a.5.5 0 0 0 .5-.5V2.707l3.146 3.147a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 1 0 .708.708L7.5 2.707V14.5a.5.5 0 0 0 .5.5z"
  }));
}
/* eslint-enable max-len */

function ownKeys$a(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$a(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$a(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$a(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function SortOrderButton(_ref) {
  var isAsc = _ref.isAsc,
      onChange = _ref.onChange,
      id = _ref.id;

  var handleButtonClick = function handleButtonClick() {
    if (!isAsc) {
      onChange(true);
    } else onChange(false);
  };

  var buttonLabel = isAsc ? 'asc' : 'desc';
  var arrowStyles = {
    width: '1em',
    height: '1em',
    transform: !isAsc ? 'scaleY(-1)' : undefined
  };
  return /*#__PURE__*/React__default.createElement(StyleUtilsContext.Consumer, null, function (_ref2) {
    var styling = _ref2.styling;
    return /*#__PURE__*/React__default.createElement("button", _objectSpread$a({
      type: "button",
      id: id,
      onClick: handleButtonClick,
      "aria-pressed": isAsc
    }, styling(['sortButton'])), /*#__PURE__*/React__default.createElement(ArrowUpIcon, {
      style: arrowStyles
    }), buttonLabel);
  });
}

function ownKeys$9(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$9(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$9(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$9(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
// from https://commons.wikimedia.org/wiki/File:OOjs_UI_icon_regular-expression.svg

function RegexIcon(props) {
  return /*#__PURE__*/React.createElement("svg", _objectSpread$9(_objectSpread$9({
    fill: "currentColor"
  }, props), {}, {
    viewBox: "0 0 24 24"
  }), /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("path", {
    d: "M3 12.045c0-.99.15-1.915.45-2.777A6.886 6.886 0 0 1 4.764 7H6.23a7.923 7.923 0 0 0-1.25 2.374 8.563 8.563 0 0 0 .007 5.314c.29.85.7 1.622 1.23 2.312h-1.45a6.53 6.53 0 0 1-1.314-2.223 8.126 8.126 0 0 1-.45-2.732"
  }), /*#__PURE__*/React.createElement("path", {
    id: "dot",
    d: "M10 16a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M14.25 7.013l-.24 2.156 2.187-.61.193 1.47-1.992.14 1.307 1.74-1.33.71-.914-1.833-.8 1.822-1.38-.698 1.296-1.74-1.98-.152.23-1.464 2.14.61-.24-2.158h1.534"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M21 12.045c0 .982-.152 1.896-.457 2.744A6.51 6.51 0 0 1 19.236 17h-1.453a8.017 8.017 0 0 0 1.225-2.31c.29-.855.434-1.74.434-2.66 0-.91-.14-1.797-.422-2.66a7.913 7.913 0 0 0-1.248-2.374h1.465a6.764 6.764 0 0 1 1.313 2.28c.3.86.45 1.782.45 2.764"
  })));
}

function ownKeys$8(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$8(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$8(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$8(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _createSuper$b(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct$b(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct$b() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
var selectId = 'rtk-query-comp-select';
var searchId = 'rtk-query-search-query';
var filterSelectId = 'rtk-query-search-query-select';
var searchPlaceholder = 'filter query by...';
var labels = {
  regexToggle: {
    info: 'Use regular expression search',
    error: 'Invalid regular expression provided'
  }
};
var QueryForm = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(QueryForm, _React$PureComponent);

  var _super = _createSuper$b(QueryForm);

  function QueryForm(props) {
    var _this;

    _classCallCheck(this, QueryForm);

    _this = _super.call(this, props);
    _this.inputSearchRef = /*#__PURE__*/React__default.createRef();

    _this.handleSubmit = function (evt) {
      evt.preventDefault();
    };

    _this.handleButtonGroupClick = function (isAsc) {
      _this.props.onFormValuesChange({
        isAscendingQueryComparatorOrder: isAsc
      });
    };

    _this.handleSelectComparatorChange = function (option) {
      if (typeof (option === null || option === void 0 ? void 0 : option.value) === 'string') {
        _this.props.onFormValuesChange({
          queryComparator: option.value
        });
      }
    };

    _this.handleSelectFilterChange = function (option) {
      if (typeof (option === null || option === void 0 ? void 0 : option.value) === 'string') {
        _this.props.onFormValuesChange({
          queryFilter: option.value
        });
      }
    };

    _this.handleRegexSearchClick = function () {
      _this.props.onFormValuesChange({
        isRegexSearch: !_this.props.values.isRegexSearch
      });
    };

    _this.restoreCaretPosition = function (start, end) {
      window.requestAnimationFrame(function () {
        if (_this.inputSearchRef.current) {
          _this.inputSearchRef.current.selectionStart = start;
          _this.inputSearchRef.current.selectionEnd = end;
        }
      });
    };

    _this.invalidateSearchValueFromProps = debounce(function () {
      _this.props.onFormValuesChange({
        searchValue: _this.state.searchValue
      });
    }, 150);

    _this.handleSearchChange = function (evt) {
      var searchValue = evt.target.value.trim();

      _this.setState({
        searchValue: searchValue
      });

      _this.invalidateSearchValueFromProps();
    };

    _this.handleClearSearchClick = function (evt) {
      evt.preventDefault();

      if (_this.state.searchValue) {
        _this.setState({
          searchValue: ''
        });

        _this.invalidateSearchValueFromProps();
      }
    };

    _this.state = {
      searchValue: props.values.searchValue
    };
    return _this;
  }

  _createClass(QueryForm, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          searchQueryRegex = _this$props.searchQueryRegex,
          _this$props$values = _this$props.values,
          isAsc = _this$props$values.isAscendingQueryComparatorOrder,
          queryComparator = _this$props$values.queryComparator,
          searchValue = _this$props$values.searchValue,
          queryFilter = _this$props$values.queryFilter,
          isRegexSearch = _this$props$values.isRegexSearch;
      var isRegexInvalid = isRegexSearch && searchValue.length > 0 && searchQueryRegex == null;
      var regexToggleType = isRegexInvalid ? 'error' : 'info';
      var regexToggleLabel = labels.regexToggle[regexToggleType];
      return /*#__PURE__*/React__default.createElement(StyleUtilsContext.Consumer, null, function (_ref) {
        var styling = _ref.styling,
            base16Theme = _ref.base16Theme;
        return /*#__PURE__*/React__default.createElement("form", _objectSpread$8({
          action: "#",
          onSubmit: _this2.handleSubmit
        }, styling('queryForm')), /*#__PURE__*/React__default.createElement("div", _objectSpread$8({}, styling('queryListHeader')), /*#__PURE__*/React__default.createElement("label", _objectSpread$8({
          htmlFor: searchId
        }, styling('srOnly')), "filter query"), /*#__PURE__*/React__default.createElement("div", _objectSpread$8({}, styling('querySearch')), /*#__PURE__*/React__default.createElement("input", {
          ref: _this2.inputSearchRef,
          type: "search",
          value: _this2.state.searchValue,
          onChange: _this2.handleSearchChange,
          placeholder: searchPlaceholder
        }), /*#__PURE__*/React__default.createElement("button", _objectSpread$8({
          type: "reset",
          "aria-label": "clear search",
          "data-invisible": +(_this2.state.searchValue.length === 0) || undefined,
          onClick: _this2.handleClearSearchClick
        }, styling('closeButton'))), /*#__PURE__*/React__default.createElement("button", _objectSpread$8({
          type: "button",
          "aria-label": regexToggleLabel,
          title: regexToggleLabel,
          "data-type": regexToggleType,
          "aria-pressed": isRegexSearch,
          onClick: _this2.handleRegexSearchClick
        }, styling('toggleButton')), /*#__PURE__*/React__default.createElement(RegexIcon, null))), /*#__PURE__*/React__default.createElement("label", _objectSpread$8({
          htmlFor: selectId
        }, styling('srOnly')), "filter by"), /*#__PURE__*/React__default.createElement(Select, {
          id: filterSelectId,
          isSearchable: false,
          options: filterQueryOptions,
          theme: base16Theme,
          value: filterQueryOptions.find(function (opt) {
            return (opt === null || opt === void 0 ? void 0 : opt.value) === queryFilter;
          }),
          onChange: _this2.handleSelectFilterChange
        })), /*#__PURE__*/React__default.createElement("div", _objectSpread$8({}, styling('sortBySection')), /*#__PURE__*/React__default.createElement("label", {
          htmlFor: selectId
        }, "Sort by"), /*#__PURE__*/React__default.createElement(Select, {
          id: selectId,
          isSearchable: false,
          theme: base16Theme,
          value: sortQueryOptions.find(function (opt) {
            return (opt === null || opt === void 0 ? void 0 : opt.value) === queryComparator;
          }),
          options: sortQueryOptions,
          onChange: _this2.handleSelectComparatorChange
        }), /*#__PURE__*/React__default.createElement(SortOrderButton, {
          id: 'rtk-query-sort-order-button',
          isAsc: isAsc,
          onChange: _this2.handleButtonGroupClick
        })));
      });
    }
  }]);

  return QueryForm;
}(React__default.PureComponent);

function isIterable(obj) {
  return obj !== null && _typeof(obj) === 'object' && !Array.isArray(obj) && typeof obj[window.Symbol.iterator] === 'function';
}

function ownKeys$7(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$7(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$7(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$7(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
var IS_IMMUTABLE_KEY = '@@__IS_IMMUTABLE__@@';

function isImmutable(value) {
  return isKeyed(value) || isIndexed(value) || isCollection(value);
}

function getShortTypeString(val, diff) {
  if (diff && Array.isArray(val)) {
    val = val[val.length === 2 ? 1 : 0];
  }

  if (isIterable(val) && !isImmutable(val)) {
    return '(…)';
  } else if (Array.isArray(val)) {
    return val.length > 0 ? '[…]' : '[]';
  } else if (val === null) {
    return 'null';
  } else if (val === undefined) {
    return 'undef';
  } else if (_typeof(val) === 'object') {
    return Object.keys(val).length > 0 ? '{…}' : '{}';
  } else if (typeof val === 'function') {
    return 'fn';
  } else if (typeof val === 'string') {
    return "\"".concat(val.substr(0, 10) + (val.length > 10 ? '…' : ''), "\"");
  } else if (_typeof(val) === 'symbol') {
    return 'symbol';
  } else {
    return val;
  }
}

function getText(type, data, previewContent, isDiff) {
  if (type === 'Object') {
    // eslint-disable-next-line @typescript-eslint/ban-types
    var keys = Object.keys(data);
    if (!previewContent) return keys.length ? '{…}' : '{}';
    var str = keys.slice(0, 3).map(function (key) {
      return "".concat(key, ": ").concat(getShortTypeString(data[key], isDiff));
    }).concat(keys.length > 3 ? ['…'] : []).join(', ');
    return "{ ".concat(str, " }");
  } else if (type === 'Array') {
    if (!previewContent) return data.length ? '[…]' : '[]';

    var _str = data.slice(0, 4).map(function (val) {
      return getShortTypeString(val, isDiff);
    }).concat(data.length > 4 ? ['…'] : []).join(', ');

    return "[".concat(_str, "]");
  } else {
    return type;
  }
}

function getItemString(styling, type, data, dataTypeKey, previewContent, isDiff) {
  return /*#__PURE__*/React__default.createElement("span", _objectSpread$7({}, styling('treeItemHint')), data[IS_IMMUTABLE_KEY] ? 'Immutable' : '', dataTypeKey && data[dataTypeKey] ? "".concat(data[dataTypeKey], " ") : '', getText(type, data, previewContent, isDiff));
}
function createTreeItemLabelRenderer(styling) {
  return function labelRenderer(_ref, nodeType, expanded) {
    var _ref2 = _slicedToArray(_ref, 1),
        key = _ref2[0];

    return /*#__PURE__*/React__default.createElement("span", null, /*#__PURE__*/React__default.createElement("span", _objectSpread$7({}, styling('treeItemKey')), key), !expanded && ': ');
  };
}

function ownKeys$6(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$6(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$6(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$6(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _createSuper$a(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct$a(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct$a() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
var QueryPreviewHeader = /*#__PURE__*/function (_React$Component) {
  _inherits(QueryPreviewHeader, _React$Component);

  var _super = _createSuper$a(QueryPreviewHeader);

  function QueryPreviewHeader() {
    var _this;

    _classCallCheck(this, QueryPreviewHeader);

    _this = _super.apply(this, arguments);

    _this.handleTabClick = function (tab) {
      if (_this.props.selectedTab !== tab.value) {
        _this.props.onTabChange(tab.value);
      }
    };

    return _this;
  }

  _createClass(QueryPreviewHeader, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          tabs = _this$props.tabs,
          selectedTab = _this$props.selectedTab,
          renderTabLabel = _this$props.renderTabLabel;
      return /*#__PURE__*/React__default.createElement(StyleUtilsContext.Consumer, null, function (_ref) {
        var styling = _ref.styling;
        return /*#__PURE__*/React__default.createElement("div", _objectSpread$6({}, styling('previewHeader')), /*#__PURE__*/React__default.createElement("div", _objectSpread$6({}, styling('tabSelector')), tabs.map(function (tab) {
          return /*#__PURE__*/React__default.createElement("div", _objectSpread$6({
            onClick: function onClick() {
              return _this2.handleTabClick(tab);
            },
            key: tab.value
          }, styling(['selectorButton', tab.value === selectedTab && 'selectorButtonSelected'], tab.value === selectedTab)), /*#__PURE__*/React__default.createElement("span", null, renderTabLabel ? renderTabLabel(tab) : tab.label));
        })));
      });
    }
  }]);

  return QueryPreviewHeader;
}(React__default.Component);
QueryPreviewHeader.defaultProps = {
  tabs: emptyArray
};

function ownKeys$5(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$5(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$5(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$5(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _createSuper$9(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct$9(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct$9() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
var TreeView = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(TreeView, _React$PureComponent);

  var _super = _createSuper$9(TreeView);

  function TreeView(props) {
    var _this;

    _classCallCheck(this, TreeView);

    _this = _super.call(this, props);
    _this.selectLabelRenderer = createSelector(identity, createTreeItemLabelRenderer);
    _this.selectGetItemString = createSelector(identity, function (styling) {
      return function (type, data) {
        return getItemString(styling, type, data, DATA_TYPE_KEY, false);
      };
    });
    _this.selectTheme = createSelector(identity, getJsonTreeTheme);
    return _this;
  }

  _createClass(TreeView, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          data = _this$props.data,
          before = _this$props.before,
          after = _this$props.after,
          children = _this$props.children,
          keyPath = _this$props.keyPath,
          shouldExpandNode = _this$props.shouldExpandNode,
          hideRoot = _this$props.hideRoot;
      return /*#__PURE__*/React__default.createElement(StyleUtilsContext.Consumer, null, function (_ref) {
        var styling = _ref.styling,
            invertTheme = _ref.invertTheme,
            base16Theme = _ref.base16Theme;
        return /*#__PURE__*/React__default.createElement("div", _objectSpread$5({}, styling('treeWrapper')), before, /*#__PURE__*/React__default.createElement(JSONTree, {
          keyPath: keyPath,
          shouldExpandNode: shouldExpandNode,
          data: data,
          labelRenderer: _this2.selectLabelRenderer(styling),
          theme: _this2.selectTheme(base16Theme),
          invertTheme: invertTheme,
          getItemString: _this2.selectGetItemString(styling),
          hideRoot: hideRoot
        }), after, children);
      });
    }
  }]);

  return TreeView;
}(React__default.PureComponent);
TreeView.defaultProps = {
  hideRoot: true,
  shouldExpandNode: function shouldExpandNode(keyPath, value, layer) {
    return layer < 2;
  }
};

function _createSuper$8(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct$8(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct$8() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
var QueryPreviewInfo = /*#__PURE__*/function (_PureComponent) {
  _inherits(QueryPreviewInfo, _PureComponent);

  var _super = _createSuper$8(QueryPreviewInfo);

  function QueryPreviewInfo() {
    var _this;

    _classCallCheck(this, QueryPreviewInfo);

    _this = _super.apply(this, arguments);

    _this.shouldExpandNode = function (keyPath, value, layer) {
      var lastKey = keyPath[keyPath.length - 1];
      return layer <= 1 && lastKey !== 'query' && lastKey !== 'mutation';
    };

    _this.selectFormattedQuery = createSelector(identity, function (resInfo) {
      var state = resInfo.state,
          queryKey = resInfo.queryKey,
          reducerPath = resInfo.reducerPath;
      var startedAt = state.startedTimeStamp ? new Date(state.startedTimeStamp).toISOString() : '-';
      var loadedAt = state.fulfilledTimeStamp ? new Date(state.fulfilledTimeStamp).toISOString() : '-';
      var statusFlags = getQueryStatusFlags(state);
      var timings = {
        startedAt: startedAt,
        loadedAt: loadedAt,
        duration: '-'
      };

      if (state.fulfilledTimeStamp && state.startedTimeStamp && state.status !== QueryStatus$1.pending && state.startedTimeStamp <= state.fulfilledTimeStamp) {
        timings.duration = formatMs(state.fulfilledTimeStamp - state.startedTimeStamp);
      }

      if (resInfo.type === 'query') {
        return {
          key: queryKey,
          reducerPath: reducerPath,
          query: resInfo.state,
          statusFlags: statusFlags,
          timings: timings
        };
      }

      return {
        key: queryKey,
        reducerPath: reducerPath,
        mutation: resInfo.state,
        statusFlags: statusFlags,
        timings: timings
      };
    });
    return _this;
  }

  _createClass(QueryPreviewInfo, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          resInfo = _this$props.resInfo,
          isWideLayout = _this$props.isWideLayout;
      var formattedQuery = this.selectFormattedQuery(resInfo);
      return /*#__PURE__*/React__default.createElement(TreeView, {
        data: formattedQuery,
        isWideLayout: isWideLayout,
        shouldExpandNode: this.shouldExpandNode
      });
    }
  }]);

  return QueryPreviewInfo;
}(PureComponent);

function ownKeys$4(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$4(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$4(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$4(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _createSuper$7(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct$7(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct$7() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
var QueryPreviewApi = /*#__PURE__*/function (_PureComponent) {
  _inherits(QueryPreviewApi, _PureComponent);

  var _super = _createSuper$7(QueryPreviewApi);

  function QueryPreviewApi() {
    var _this;

    _classCallCheck(this, QueryPreviewApi);

    _this = _super.apply(this, arguments);

    _this.shouldExpandApiStateNode = function (keyPath, value, layer) {
      var lastKey = keyPath[keyPath.length - 1];
      return layer <= 1 && lastKey !== 'config';
    };

    return _this;
  }

  _createClass(QueryPreviewApi, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          apiStats = _this$props.apiStats,
          isWideLayout = _this$props.isWideLayout,
          apiState = _this$props.apiState;

      if (!apiState) {
        return null;
      }

      var hasMutations = Object.keys(apiState.mutations).length > 0;
      var hasQueries = Object.keys(apiState.queries).length > 0;
      return /*#__PURE__*/React__default.createElement(StyleUtilsContext.Consumer, null, function (_ref) {
        var styling = _ref.styling;
        return /*#__PURE__*/React__default.createElement("article", _objectSpread$4({}, styling('tabContent')), /*#__PURE__*/React__default.createElement("h2", null, apiState.config.reducerPath), /*#__PURE__*/React__default.createElement(TreeView, {
          before: /*#__PURE__*/React__default.createElement("h3", null, "State"),
          data: apiState,
          shouldExpandNode: _this2.shouldExpandApiStateNode,
          isWideLayout: isWideLayout
        }), apiStats && /*#__PURE__*/React__default.createElement(React__default.Fragment, null, /*#__PURE__*/React__default.createElement(TreeView, {
          before: /*#__PURE__*/React__default.createElement("h3", null, "Tally"),
          data: apiStats.tally,
          isWideLayout: isWideLayout
        }), hasQueries && /*#__PURE__*/React__default.createElement(TreeView, {
          before: /*#__PURE__*/React__default.createElement("h3", null, "Queries Timings"),
          data: apiStats.timings.queries,
          isWideLayout: isWideLayout
        }), hasMutations && /*#__PURE__*/React__default.createElement(TreeView, {
          before: /*#__PURE__*/React__default.createElement("h3", null, "Mutations Timings"),
          data: apiStats.timings.mutations,
          isWideLayout: isWideLayout
        })));
      });
    }
  }]);

  return QueryPreviewApi;
}(PureComponent);

function _createSuper$6(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct$6(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct$6() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
var QueryPreviewSubscriptions = /*#__PURE__*/function (_PureComponent) {
  _inherits(QueryPreviewSubscriptions, _PureComponent);

  var _super = _createSuper$6(QueryPreviewSubscriptions);

  function QueryPreviewSubscriptions() {
    _classCallCheck(this, QueryPreviewSubscriptions);

    return _super.apply(this, arguments);
  }

  _createClass(QueryPreviewSubscriptions, [{
    key: "render",
    value: function render() {
      var subscriptions = this.props.subscriptions;
      return /*#__PURE__*/React__default.createElement(TreeView, {
        data: subscriptions,
        isWideLayout: this.props.isWideLayout
      });
    }
  }]);

  return QueryPreviewSubscriptions;
}(PureComponent);

function _createSuper$5(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct$5(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct$5() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
var QueryPreviewTags = /*#__PURE__*/function (_PureComponent) {
  _inherits(QueryPreviewTags, _PureComponent);

  var _super = _createSuper$5(QueryPreviewTags);

  function QueryPreviewTags(props) {
    var _this;

    _classCallCheck(this, QueryPreviewTags);

    _this = _super.call(this, props);
    _this.state = {
      data: {
        tags: props.tags
      }
    };
    return _this;
  }

  _createClass(QueryPreviewTags, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          isWideLayout = _this$props.isWideLayout,
          tags = _this$props.tags;
      return /*#__PURE__*/React__default.createElement(TreeView, {
        data: tags,
        isWideLayout: isWideLayout
      });
    }
  }]);

  return QueryPreviewTags;
}(PureComponent);

function ownKeys$3(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$3(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$3(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$3(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function NoRtkQueryApi() {
  return /*#__PURE__*/React__default.createElement(StyleUtilsContext.Consumer, null, function (_ref) {
    var styling = _ref.styling;
    return /*#__PURE__*/React__default.createElement("div", _objectSpread$3({}, styling('noApiFound')), "No rtk-query api found.", /*#__PURE__*/React__default.createElement("br", null), "Make sure to follow", ' ', /*#__PURE__*/React__default.createElement("a", {
      href: "https://redux-toolkit.js.org/rtk-query/overview#basic-usage",
      target: "_blank",
      rel: "noreferrer noopener"
    }, "the instructions"), ".");
  });
}

function ownKeys$2(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$2(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$2(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$2(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _createSuper$4(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct$4(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct$4() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
function mapProps(mapper) {
  return function mapPropsHoc(Comp) {
    var MapPropsHoc = /*#__PURE__*/function (_Component) {
      _inherits(MapPropsHoc, _Component);

      var _super = _createSuper$4(MapPropsHoc);

      function MapPropsHoc() {
        _classCallCheck(this, MapPropsHoc);

        return _super.apply(this, arguments);
      }

      _createClass(MapPropsHoc, [{
        key: "render",
        value: function render() {
          var mappedProps = mapper(this.props);
          return /*#__PURE__*/React__default.createElement(Comp, _objectSpread$2({}, mappedProps));
        }
      }]);

      return MapPropsHoc;
    }(Component);

    MapPropsHoc.displayName = "mapProps(".concat(Comp.displayName || Comp.name || 'Component', ")");
    return MapPropsHoc;
  };
}

function _createSuper$3(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct$3(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct$3() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
var keySep = ' - ';
var QueryPreviewActions = /*#__PURE__*/function (_PureComponent) {
  _inherits(QueryPreviewActions, _PureComponent);

  var _super = _createSuper$3(QueryPreviewActions);

  function QueryPreviewActions() {
    var _this;

    _classCallCheck(this, QueryPreviewActions);

    _this = _super.apply(this, arguments);
    _this.selectFormattedActions = createSelector(identity, function (actions) {
      var output = {};

      if (actions.length === 0) {
        return emptyRecord;
      }

      for (var i = 0, len = actions.length; i < len; i++) {
        var _action$type;

        var action = actions[i];
        var key = "".concat(i).concat(keySep).concat((_action$type = action === null || action === void 0 ? void 0 : action.type) !== null && _action$type !== void 0 ? _action$type : '');
        output[key] = action;
      }

      return output;
    });

    _this.isLastActionNode = function (keyPath, layer) {
      if (layer >= 1) {
        var len = _this.props.actionsOfQuery.length;
        var actionKey = keyPath[keyPath.length - 1];

        if (typeof actionKey === 'string') {
          var index = Number(actionKey.split(keySep)[0]);
          return len > 0 && len - index < 2;
        }
      }

      return false;
    };

    _this.shouldExpandNode = function (keyPath, value, layer) {
      if (layer === 1) {
        return _this.isLastActionNode(keyPath, layer);
      }

      if (layer === 2) {
        return _this.isLastActionNode(keyPath, layer) && (keyPath[0] === 'meta' || keyPath[0] === 'error');
      }

      return layer <= 1;
    };

    return _this;
  }

  _createClass(QueryPreviewActions, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          isWideLayout = _this$props.isWideLayout,
          actionsOfQuery = _this$props.actionsOfQuery;
      return /*#__PURE__*/React__default.createElement(TreeView, {
        data: this.selectFormattedActions(actionsOfQuery),
        isWideLayout: isWideLayout,
        shouldExpandNode: this.shouldExpandNode
      });
    }
  }]);

  return QueryPreviewActions;
}(PureComponent);

function isTabVisible(tab, visKey) {
  if (typeof tab.visible === 'boolean') {
    return tab.visible;
  }

  if (_typeof(tab.visible) === 'object' && tab.visible) {
    return !!tab.visible[visKey];
  }

  return true;
}

function ownKeys$1(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$1(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$1(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$1(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _createSuper$2(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct$2(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct$2() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
var MappedQueryPreviewTags = mapProps(function (_ref) {
  var selectors = _ref.selectors,
      selectorsSource = _ref.selectorsSource,
      isWideLayout = _ref.isWideLayout,
      resInfo = _ref.resInfo;
  return {
    resInfo: resInfo,
    tags: selectors.selectCurrentQueryTags(selectorsSource),
    isWideLayout: isWideLayout
  };
})(QueryPreviewTags);
var MappedQueryPreviewInfo = mapProps(function (_ref2) {
  var resInfo = _ref2.resInfo,
      isWideLayout = _ref2.isWideLayout;
  return {
    resInfo: resInfo,
    isWideLayout: isWideLayout
  };
})(QueryPreviewInfo);
var MappedQuerySubscriptipns = mapProps(function (_ref3) {
  var selectors = _ref3.selectors,
      selectorsSource = _ref3.selectorsSource,
      isWideLayout = _ref3.isWideLayout;
  return {
    isWideLayout: isWideLayout,
    subscriptions: selectors.selectSubscriptionsOfCurrentQuery(selectorsSource)
  };
})(QueryPreviewSubscriptions);
var MappedApiPreview = mapProps(function (_ref4) {
  var isWideLayout = _ref4.isWideLayout,
      selectors = _ref4.selectors,
      selectorsSource = _ref4.selectorsSource;
  return {
    isWideLayout: isWideLayout,
    apiState: selectors.selectApiOfCurrentQuery(selectorsSource),
    apiStats: selectors.selectApiStatsOfCurrentQuery(selectorsSource)
  };
})(QueryPreviewApi);
var MappedQueryPreviewActions = mapProps(function (_ref5) {
  var isWideLayout = _ref5.isWideLayout,
      selectorsSource = _ref5.selectorsSource,
      selectors = _ref5.selectors;
  return {
    isWideLayout: isWideLayout,
    actionsOfQuery: selectors.selectActionsOfCurrentQuery(selectorsSource)
  };
})(QueryPreviewActions);
var tabs = [{
  label: 'Query',
  value: QueryPreviewTabs.queryinfo,
  component: MappedQueryPreviewInfo,
  visible: {
    query: true,
    mutation: true,
    default: true
  }
}, {
  label: 'Actions',
  value: QueryPreviewTabs.actions,
  component: MappedQueryPreviewActions,
  visible: {
    query: true,
    mutation: true,
    default: true
  }
}, {
  label: 'Tags',
  value: QueryPreviewTabs.queryTags,
  component: MappedQueryPreviewTags,
  visible: {
    query: true,
    mutation: false,
    default: true
  }
}, {
  label: 'Subs',
  value: QueryPreviewTabs.querySubscriptions,
  component: MappedQuerySubscriptipns,
  visible: {
    query: true,
    mutation: false,
    default: true
  }
}, {
  label: 'Api',
  value: QueryPreviewTabs.apiConfig,
  component: MappedApiPreview
}];
var QueryPreview = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(QueryPreview, _React$PureComponent);

  var _super = _createSuper$2(QueryPreview);

  function QueryPreview(props) {
    var _this;

    _classCallCheck(this, QueryPreview);

    _this = _super.call(this, props);

    _this.renderLabelWithCounter = function (label, counter) {
      var counterAsString = counter.toFixed(0);

      if (counterAsString.length > 3) {
        counterAsString = counterAsString.slice(0, 2) + '...';
      }

      return "".concat(label, "(").concat(counterAsString, ")");
    };

    _this.renderTabLabel = function (tab) {
      var _this$props = _this.props,
          selectors = _this$props.selectors,
          selectorsSource = _this$props.selectorsSource,
          resInfo = _this$props.resInfo;
      var tabCount = selectors.selectTabCounters(selectorsSource)[tab.value];
      var tabLabel = tab.label;

      if (tabLabel === 'query' && (resInfo === null || resInfo === void 0 ? void 0 : resInfo.type) === 'mutation') {
        tabLabel = resInfo.type;
      }

      if (tabCount > 0) {
        return _this.renderLabelWithCounter(tabLabel, tabCount);
      }

      return tabLabel;
    };

    _this.labelRenderer = createTreeItemLabelRenderer(_this.props.styling);
    return _this;
  }

  _createClass(QueryPreview, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props2 = this.props,
          resInfo = _this$props2.resInfo,
          selectedTab = _this$props2.selectedTab,
          onTabChange = _this$props2.onTabChange,
          hasNoApis = _this$props2.hasNoApis;

      var _ref6 = tabs.find(function (tab) {
        return tab.value === selectedTab;
      }) || tabs[0],
          TabComponent = _ref6.component;

      if (!resInfo) {
        return /*#__PURE__*/React__default.createElement(StyleUtilsContext.Consumer, null, function (_ref7) {
          var styling = _ref7.styling;
          return /*#__PURE__*/React__default.createElement("div", _objectSpread$1({}, styling('queryPreview')), /*#__PURE__*/React__default.createElement(QueryPreviewHeader, {
            selectedTab: selectedTab,
            onTabChange: onTabChange,
            tabs: tabs.filter(function (tab) {
              return isTabVisible(tab, 'default');
            }),
            renderTabLabel: _this2.renderTabLabel
          }), hasNoApis && /*#__PURE__*/React__default.createElement(NoRtkQueryApi, null));
        });
      }

      return /*#__PURE__*/React__default.createElement(StyleUtilsContext.Consumer, null, function (_ref8) {
        var styling = _ref8.styling;
        return /*#__PURE__*/React__default.createElement("div", _objectSpread$1({}, styling('queryPreview')), /*#__PURE__*/React__default.createElement(QueryPreviewHeader, {
          selectedTab: selectedTab,
          onTabChange: onTabChange,
          tabs: tabs.filter(function (tab) {
            return isTabVisible(tab, resInfo.type);
          }),
          renderTabLabel: _this2.renderTabLabel
        }), /*#__PURE__*/React__default.createElement(TabComponent, _objectSpread$1({}, _this2.props)));
      });
    }
  }]);

  return QueryPreview;
}(React__default.PureComponent);

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _createSuper$1(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct$1(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct$1() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var RtkQueryInspector = /*#__PURE__*/function (_PureComponent) {
  _inherits(RtkQueryInspector, _PureComponent);

  var _super = _createSuper$1(RtkQueryInspector);

  function RtkQueryInspector(props) {
    var _this;

    _classCallCheck(this, RtkQueryInspector);

    _this = _super.call(this, props);
    _this.inspectorRef = /*#__PURE__*/createRef();
    _this.isWideIntervalRef = null;
    _this.selectors = createInspectorSelectors();

    _this.updateSizeMode = function () {
      if (_this.inspectorRef.current) {
        var isWideLayout = _this.inspectorRef.current.offsetWidth >= RtkQueryInspector.wideLayout;

        if (isWideLayout !== _this.state.isWideLayout) {
          _this.setState({
            isWideLayout: isWideLayout
          });
        }
      }
    };

    _this.handleQueryFormValuesChange = function (values) {
      _this.props.dispatch(changeQueryFormValues(values));
    };

    _this.handleSelectQuery = function (queryInfo) {
      _this.props.dispatch(selectQueryKey(queryInfo));
    };

    _this.handleTabChange = function (tab) {
      _this.props.dispatch(selectedPreviewTab(tab));
    };

    _this.state = {
      isWideLayout: true,
      selectorsSource: computeSelectorSource(props, null)
    };
    return _this;
  }

  _createClass(RtkQueryInspector, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.updateSizeMode();
      this.isWideIntervalRef = setInterval(this.updateSizeMode, 300);
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this.isWideIntervalRef) {
        clearTimeout(this.isWideIntervalRef);
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$state = this.state,
          selectorsSource = _this$state.selectorsSource,
          isWideLayout = _this$state.isWideLayout;
      var styling = this.props.styleUtils.styling;
      var allVisibleRtkResourceInfos = this.selectors.selectAllVisbileQueries(selectorsSource);
      var currentResInfo = this.selectors.selectCurrentQueryInfo(selectorsSource);
      var apiStates = this.selectors.selectApiStates(selectorsSource);
      var hasNoApi = apiStates == null;
      var searchQueryRegex = this.selectors.selectSearchQueryRegex(selectorsSource);
      return /*#__PURE__*/React__default.createElement("div", _objectSpread({
        ref: this.inspectorRef,
        "data-wide-layout": +this.state.isWideLayout
      }, styling('inspector')), /*#__PURE__*/React__default.createElement("div", _objectSpread(_objectSpread({}, styling('querySectionWrapper')), {}, {
        "data-wide-layout": +this.state.isWideLayout
      }), /*#__PURE__*/React__default.createElement(QueryForm, {
        searchQueryRegex: searchQueryRegex,
        values: selectorsSource.monitorState.queryForm.values,
        onFormValuesChange: this.handleQueryFormValuesChange
      }), /*#__PURE__*/React__default.createElement(QueryList, {
        onSelectQuery: this.handleSelectQuery,
        resInfos: allVisibleRtkResourceInfos,
        selectedQueryKey: selectorsSource.monitorState.selectedQueryKey
      })), /*#__PURE__*/React__default.createElement(QueryPreview, {
        selectorsSource: this.state.selectorsSource,
        selectors: this.selectors,
        resInfo: currentResInfo,
        selectedTab: selectorsSource.monitorState.selectedPreviewTab,
        onTabChange: this.handleTabChange,
        styling: styling,
        isWideLayout: isWideLayout,
        hasNoApis: hasNoApi
      }));
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(props, state) {
      var selectorsSource = computeSelectorSource(props, state.selectorsSource);

      if (selectorsSource !== state.selectorsSource) {
        return {
          selectorsSource: selectorsSource
        };
      }

      return null;
    }
  }]);

  return RtkQueryInspector;
}(PureComponent);

RtkQueryInspector.wideLayout = 600;

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var RtkQueryMonitor = /*#__PURE__*/function (_Component) {
  _inherits(RtkQueryMonitor, _Component);

  var _super = _createSuper(RtkQueryMonitor);

  function RtkQueryMonitor(props) {
    var _this;

    _classCallCheck(this, RtkQueryMonitor);

    _this = _super.call(this, props);
    _this.state = {
      styleUtils: createThemeState(props)
    };
    return _this;
  }

  _createClass(RtkQueryMonitor, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          currentStateIndex = _this$props.currentStateIndex,
          computedStates = _this$props.computedStates,
          monitorState = _this$props.monitorState,
          dispatch = _this$props.dispatch,
          actionsById = _this$props.actionsById;
      return /*#__PURE__*/React__default.createElement(StyleUtilsContext.Provider, {
        value: this.state.styleUtils
      }, /*#__PURE__*/React__default.createElement(RtkQueryInspector, {
        computedStates: computedStates,
        currentStateIndex: currentStateIndex,
        monitorState: monitorState,
        dispatch: dispatch,
        styleUtils: this.state.styleUtils,
        actionsById: actionsById
      }));
    }
  }]);

  return RtkQueryMonitor;
}(Component);

RtkQueryMonitor.update = reducer;
RtkQueryMonitor.propTypes = {
  dispatch: PropTypes.func,
  computedStates: PropTypes.array,
  currentStateIndex: PropTypes.number,
  actionsById: PropTypes.object,
  stagedActionIds: PropTypes.array,
  skippedActionIds: PropTypes.array,
  monitorState: PropTypes.object,
  theme: PropTypes.oneOfType([PropTypes.object, PropTypes.string]),
  invertTheme: PropTypes.bool
};
RtkQueryMonitor.defaultProps = {
  theme: 'nicinabox',
  invertTheme: false
};

export { RtkQueryMonitor };
